
/*************************脚本使用说明*********************************
 * 
 * 1.使用此脚本交互需本地运行易联众硬件设备服务程序。
 * 2.易联众硬件设备服务支持Http和Websocket服务请求，报文格式为JSON格式，
 *   各功能点报文格式，请见接口说明文档。开发者可自行发送报文通信或调用此
 *   脚本进行交互。
 *   HTTP请求地址：http://127.0.0.1:7776/http/hardware
 *   Websocket请求地址：ws://127.0.0.1:7776
 *   *如遇到端口冲突，可在C:\YLZ_PT_PlatForm\Config\config-plaform.ini
 *    中修改本地服务端口配置。
 *   *由于是异步通信，开发者调用相应的操作函数后，需在回调函数中处理返回结
 *    果。
 * 3.目前服务支持的硬件包括读卡器、身份证阅读器和高拍仪  
 * 
 * 更新说明：
 * 1.2020-03-11 ZQD 版本创建  
 * 2.2020-05-12 ZQD 增加同步请求方式
 * 2.1 通过修改 YLZService 入参来改变请求方式， * 入参 0：同步方式；
 *    入参 1：异步方式；测试网页默认用异步方式。
 * 2.2 同步请求时，网页会阻塞等待请求返回，返回值为一个对象。
 * 2.3 异步请求时，网页不会阻塞等待，返回结果在回调函数Callback中处理。
 * *****************************************************************/

//0:同步；1：异步
var Service = new YLZService(1);

window.console = window.console || (function () {
    var c = {}; c.log = c.warn = c.debug = c.info = c.error = c.time = c.dir = c.profile
    = c.clear = c.exception = c.trace = c.assert = function () { };
    return c;
})();


/**********************************************************
 ** 函数名称:YLZ_SSCard_ReadNo(Callback,Region,DeptID)
 ** 函数功能:实现 发送读社保卡号请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_SSCard_ReadNo(Callback,Region,DeptID)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;

    jsonPara["FunID"]  = "DKQ0001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_SSCard_ReadInfo(Callback,Region,DeptID)
 ** 函数功能:实现 发送读社保卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_SSCard_ReadInfo(Callback,Region,DeptID,DevType)
{
    var jsonItem = new Object();
    var jsonPara = new Object();
   
    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;
    jsonItem["DevType"] = DevType;

    jsonPara["FunID"]  = "DKQ0002";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_iReadCardBas_HSM_Step1(Callback,Region,DevType)
 ** 函数功能:实现基于加密机的读基本信息（步骤一）的功能
 **参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_iReadCardBas_HSM_Step1(Callback,Region,DevType)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DevType"] = DevType;

    jsonPara["FunID"]  = "DKQ1001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}
/**********************************************************
 ** 函数名称:YLZ_iReadCardBas_HSM_Step2(Callback,Region,DeptDATA,DevType)
 ** 函数功能:实现基于加密机的读基本信息（步骤二）的功能
 **参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptDATA 经加密机处理返回的鉴别数据
 * @DevType 设备型号
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_iReadCardBas_HSM_Step2(Callback,Region,DeptDATA,DevType)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptDATA"] = DeptDATA;
    jsonItem["DevType"] = DevType;
    
    jsonPara["FunID"]  = "DKQ1002";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_SSCard_ReadIdentifyNum(Callback,Region,DeptID)
 ** 函数功能:实现 发送读社保卡识别码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_SSCard_ReadIdentifyNum(Callback,Region,DeptID)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;

    jsonPara["FunID"]  = "DKQ0003";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_SSCard_ReadCity(Callback,Region)
 ** 函数功能:实现 发送读社保卡发卡地区请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_SSCard_ReadCity(Callback,Region)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;

    jsonPara["FunID"]  = "DKQ0004";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_SSCard_ReadInfo_YB(Callback,Region,DeptID,User,PassWD)
 ** 函数功能:实现 发送医保读社保卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 * @User 操作人员帐号
 * @PassWD 操作人员密码
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_SSCard_ReadInfo_YB(Callback,Region,DeptID,User,PassWD)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;
    jsonItem["User"] = User;
    jsonItem["PassWD"] = PassWD;

    jsonPara["FunID"]  = "DKQ0101";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_Device_ReadInfo_YB(Callback,Region,DeptID)
 ** 函数功能:实现 发送医保读设备序列号和PSAM卡号(加密)请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Device_ReadInfo_YB(Callback,Region,DeptID)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;

    jsonPara["FunID"]  = "DKQ0102";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_Device_ReadInfoEx_YB(Callback,Region,DeptID)
 ** 函数功能:实现 发送医保读设备序列号、PSAM卡号(加密)、IP和MAC地址请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Device_ReadInfoEx_YB(Callback,Region,DeptID)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;

    jsonPara["FunID"]  = "DKQ0103";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_Device_ReadInfoEx_YB(Callback,Region,DeptID)
 ** 函数功能:实现 解密医保读设备序列号、PSAM卡号、IP和MAC地址请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @DeptID 医保网点编号，如：厦门市湖里医院 "0507"
 * @DeptID 设备序列号(已加密)，
 * @DeptID PSAM卡号(已加密)，
 * @DeptID MAC地址(已加密)，
 * @DeptID IP地址(已加密)，
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Device_TrippleDES_YB(Callback,Region,DeptID,DevSerialID,PSAMTerminalNo,szMacAddr,szIpAddr)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;
	jsonItem["DevSerialID"] = DevSerialID;
    jsonItem["PSAMTerminalNo"] = PSAMTerminalNo;
	jsonItem["szMacAddr"] = szMacAddr;
    jsonItem["szIpAddr"] = szIpAddr;

    jsonPara["FunID"]  = "DKQ0104";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


function YLZ_Device_EnDecode(Callback,Region,DeptID,Mode)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;
	jsonItem["Mode"] = Mode;

    jsonPara["FunID"]  = "DKQ0105";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

function YLZ_Device_Decode(Callback,Region,DeptID,Mode,EnData)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DeptID"] = DeptID;
	jsonItem["Mode"] = Mode;
	jsonItem["EnData"] = EnData;

    jsonPara["FunID"]  = "DKQ0106";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}



/**********************************************************
 ** 函数名称:YLZ_IDCard_ReadInfo(Callback,Region,PhotoPath)
 ** 函数功能:实现 发送读卡器读身份证请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @PhotoPath 证件照保存文件夹（此文件夹必须已存在且有读写权限）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_IDCard_ReadInfo(Callback,Region,PhotoPath)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    
    jsonItem["Region"] = Region;
    jsonItem["PhotoPath"] = PhotoPath;

    jsonPara["FunID"]  = "DKQ0005";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_MagBankCard_ReadNo(Callback,Region,Timeout)
 ** 函数功能:实现 发送读磁条银行卡号请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Timeout 等待超时时间（单位：s）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_MagBankCard_ReadNo(Callback,Region,Timeout)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Timeout"] = Timeout;

    jsonPara["FunID"]  = "DKQ0006";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_BankCard_ReadNo(Callback,Region)
 ** 函数功能:实现 发送读芯片银行卡号请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_BankCard_ReadNo(Callback,Region)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    
    jsonItem["Region"] = Region;

    jsonPara["FunID"]  = "DKQ0007";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_KeyBoard_ReadNum(Callback,Region)
 ** 函数功能:实现 发送读密码键盘输入信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Timeout 等待超时时间（单位：s）
 * @Type 密码提示类型（仅1适合所有带键盘读卡器，2-6只适合YKT-5-II）
 * 1：请输入密码；2：请再次输入密码；3:请输入旧密码；
 * 4:请输入新密码 5:请再次输入新密码；6:密码修改成功
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_KeyBoard_ReadNum(Callback,Region,Timeout,Type)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    
    jsonItem["Region"] = Region;
    jsonItem["Timeout"] = Timeout;
    jsonItem["Type"] = Type;

    jsonPara["FunID"]  = "DKQ0008";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_MagCard_ReadInfo(Callback,Region,Timeout)
 ** 函数功能:实现 发送读磁条卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Timeout 等待超时时间（单位：s）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_MagCard_ReadInfo(Callback,Region,Timeout)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Timeout"] = Timeout;

    jsonPara["FunID"]  = "DKQ0009";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_ECard_SetAutoRead(Callback,Region,SetAutoRead)
 ** 函数功能:实现 发送设置扫码模式（YKT-5-II）请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @SetAutoRead 手动/自动扫码模式选择，0：手动扫码；1：自动扫码；
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_ECard_SetAutoRead(Callback,Region,SetAutoRead)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["SetAutoRead"] = SetAutoRead;

    jsonPara["FunID"]  = "DKQ0010";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_ECard_ReadInfo(Callback,Region,Timeout)
 ** 函数功能:实现 发送获取手动扫码信息（YKT-5-II）请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Timeout 等待超时时间（单位：s）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_ECard_ReadInfo(Callback,Region,Timeout)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Timeout"] = Timeout;

    jsonPara["FunID"]  = "DKQ0011";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_ECard_SetAutoTime(Callback,Region,Timeout)
 ** 函数功能:实现 发送设置自动扫码时间间隔（YKT-5-II）请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Timeout 等待超时时间（单位：ms）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_ECard_SetAutoTime(Callback,Region,Timeout)
{
    var jsonItem = new Object();
    var jsonPara = new Object();
    
    jsonItem["Region"] = Region;
    jsonItem["Timeout"] = Timeout;

    jsonPara["FunID"]  = "DKQ0012";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_4428_ReadInfo(Callback,Region,Offset,Length)
 ** 函数功能:实现 发送读4428卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Offset 起始地址，0-1023
 * @Length 读取数据长度，1-1024
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4428_ReadInfo(Callback,Region,Offset,Length)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Offset"] = Offset;
    jsonItem["Length"] = Length;

    jsonPara["FunID"]  = "DKQ0013";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_iVerifyPIN(Callback,Region)
 ** 函数功能:实现 校验PIN 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_iVerifyPIN(Callback,Region,DevType)
{
	var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["DevType"] = DevType;
    
    jsonPara["FunID"]  = "DKQ1003";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}
/**********************************************************
 ** 函数名称:YLZ_4428_WriteInfo(Callback,Region,Offset,WriteData)
 ** 函数功能:实现 发送写4428卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Offset 起始地址，0-1023
 * @WriteData 写入数据
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4428_WriteInfo(Callback,Region,Offset,WriteData)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Offset"] = Offset;
    jsonItem["WriteData"] = WriteData;

    jsonPara["FunID"]  = "DKQ0014";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4428_CheckPassWD(Callback,Region,PassWD)
 ** 函数功能:实现 发送校验4428卡密码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @PassWD 密码，默认密码:"FFFF"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4428_CheckPassWD(Callback,Region,PassWD)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["PassWD"] = PassWD;
  
    jsonPara["FunID"]  = "DKQ0015";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4428_ChangePassWD(Callback,Region,PassWD)
 ** 函数功能:实现 发送更改4428卡密码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @OldPassWD 旧密码
 * @NewPassWD 新密码
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4428_ChangePassWD(Callback,Region,OldPassWD,NewPassWD)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["OldPassWD"] = OldPassWD;
    jsonItem["NewPassWD"] = NewPassWD;
  
    jsonPara["FunID"]  = "DKQ0016";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4428_ErrorCount(Callback,Region,PassWD)
 ** 函数功能:实现 发送获取4428卡密码错误计数请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4428_ErrorCount(Callback,Region)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
  
    jsonPara["FunID"]  = "DKQ0017";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4442_ReadInfo(Callback,Region,Offset,Length)
 ** 函数功能:实现 发送读4442卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Offset 起始地址，0-255
 * @Length 读取数据长度，1-256
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4442_ReadInfo(Callback,Region,Offset,Length)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Offset"] = Offset;
    jsonItem["Length"] = Length;

    jsonPara["FunID"]  = "DKQ0018";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4442_WriteInfo(Callback,Region,Offset,WriteData)
 ** 函数功能:实现 发送写4442卡信息请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @Offset 起始地址，0-255
 * @WriteData 写入数据
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4442_WriteInfo(Callback,Region,Offset,WriteData)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["Offset"] = Offset;
    jsonItem["WriteData"] = WriteData;

    jsonPara["FunID"]  = "DKQ0019";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4442_CheckPassWD(Callback,Region,PassWD)
 ** 函数功能:实现 发送校验4442卡密码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @PassWD 密码，默认密码:"FFFFFF"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4442_CheckPassWD(Callback,Region,PassWD)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["PassWD"] = PassWD;
  
    jsonPara["FunID"]  = "DKQ0020";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4442_ChangePassWD(Callback,Region,PassWD)
 ** 函数功能:实现 发送更改4442卡密码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 * @OldPassWD 旧密码
 * @NewPassWD 新密码
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4442_ChangePassWD(Callback,Region,OldPassWD,NewPassWD)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
    jsonItem["OldPassWD"] = OldPassWD;
    jsonItem["NewPassWD"] = NewPassWD;
  
    jsonPara["FunID"]  = "DKQ0021";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_4442_ErrorCount(Callback,Region,PassWD)
 ** 函数功能:实现 发送获取4442卡密码错误计数请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Region 设备所在地区，如：厦门 "3502"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_4442_ErrorCount(Callback,Region)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Region"] = Region;
  
    jsonPara["FunID"]  = "DKQ0022";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_Reader_ReadIDCard(Callback,Port,Timeout,PhotoPath)
 ** 函数功能:实现 发送读身份证信息（身份证阅读器）请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Port 设备端口，1～16(十进制)为串口，1001～1016(十进制)为 USB 口
 * @Timeout 超时等待时间，单位：ms
 * @PhotoPath 证件照保存文件夹（此文件夹必须已存在且有读写权限）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Reader_ReadIDCard(Callback,Port,Timeout,PhotoPath)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Port"] = Port;
    jsonItem["Timeout"] = Timeout;
    jsonItem["PhotoPath"] = PhotoPath;
  
    jsonPara["FunID"]  = "YDQ0001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_GEN_ReadIDCard(Callback,Mode,PhotoPath)
 ** 函数功能:实现 发送读身份证信息（身份证阅读器/读卡器/高拍仪）请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Mode 
 * 0：不保存照片，不需要Base64；
 * 1：不保存照片，需要Base64；
 * 2：保存照片，需要Base64；
 * 3：保存照片，不需要Base64；
 * @PhotoPath 证件照保存文件夹（此文件夹必须有读写权限）
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_GEN_ReadIDCard(Callback,Mode,PhotoPath)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Mode"] = Mode;
    jsonItem["PhotoPath"] = PhotoPath;
  
    jsonPara["FunID"]  = "GEN0001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_GPY_PhotoAndUpload(Callback,Path,IP,Port,URI)
 ** 函数功能:实现 发送高拍仪拍照上传请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Path 图片保存目录，如："C:/xnb/"
 * @IP 服务器IP地址，如："192.168.11.105"
 * @Port 服务器端口，如："80"
 * @URI 资源名称，如："/shop"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_GPY_PhotoAndUpload(Callback)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

 

    jsonPara["FunID"]  = "GPY0001";
    

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_GPY_PhotoBase64(Callback,Path)
 ** 函数功能:实现 发送高拍仪照片BASE64转码请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Path 图片保存目录，如："C:/xnb/"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_GPY_PhotoBase64(Callback,Path)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Path"] = Path;

    jsonPara["FunID"]  = "GPY0002";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_GPY_Upload(Callback,Path,IP,Port,URI)
 ** 函数功能:实现 发送高拍仪上传请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Path 图片保存目录，如："C:/xnb/"
 * @IP 服务器IP地址，如："192.168.11.105"
 * @Port 服务器端口，如："80"
 * @URI 资源名称，如："/shop"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_GPY_Upload(Callback,Path,IP,Port,URI)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonItem["Path"] = Path;
    jsonItem["IP"] = IP;
    jsonItem["Port"] = Port;
    jsonItem["URI"] = URI;

    jsonPara["FunID"]  = "GPY0003";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_GPY_CleanCache(Callback,Path)
 ** 函数功能:实现 发送高拍仪清理缓存文件请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 * @Path 图片保存目录，如："C:/xnb/"
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_GPY_CleanCache(Callback)
{
    var jsonItem = new Object();
    var jsonPara = new Object();


    jsonPara["FunID"]  = "GPY0004";
   

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_Service_Restart(Callback)
 ** 函数功能:实现 发送重启服务请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Service_Restart(Callback)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonPara["FunID"]  = "RST0001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}

/**********************************************************
 ** 函数名称:YLZ_Service_GetVersion(Callback)
 ** 函数功能:实现 发送获取硬件服务版本请求 的功能
 ** 参    数: 
 * @Callback 回调函数，请在回调函数中处理返回结果。
 ** 返 回 值：
 * 同步请求时，返回值为结果对象；
 * 异步请求时，返回值为null,操作结果在回调函数Callback中处理。
**********************************************************/
function YLZ_Service_GetVersion(Callback)
{
    var jsonItem = new Object();
    var jsonPara = new Object();

    jsonPara["FunID"]  = "SER0001";
    jsonPara["TranData"]  = jsonItem;

    var jsonString = JSON2.stringify(jsonPara);
    var ajaxObj = Service.SendData(Callback,jsonString);
    if(ajaxObj != null)
    {
        if(ajaxObj.status != 200)
        {
            return ajaxObj;
        }
        else
        {
            return ajaxObj.responseJSON;
        }
    }
    else
    {
        return null;
    }
}


/**********************************************************
 ** 函数名称:YLZ_Service_GetBrowserInfo()
 ** 函数功能:实现 获取浏览器版本信息 的功能
 ** 参    数: 无
 ** 返 回 值: browser:浏览器内核名称；ver：浏览器版本；
**********************************************************/
function YLZ_Service_GetBrowserInfo(){
     var Sys = {};
     var ua = navigator.userAgent.toLowerCase();
     var re =/(msie|edge|firefox|chrome|opera|version).*?([\d.]+)/;
     var m = ua.match(re);
     if(m == null)
     {
        m = ua.match(/(rv).*?([\d.]+)/)
        if(m == null)
        {
            Sys.browser = "Unknown";
            Sys.ver = "0";
            return Sys;
        }
     }

    Sys.browser = m[1].replace(/version/, "Safari").replace(/msie/,"IE").replace(/rv/,"IE").replace(/firefox/,"Firefox").replace(/chrome/,"Chromium").replace(/opera/,"Opera").replace(/edge/,"Edge");
    Sys.ver = m[2];   

     return Sys;
 }

 /**********************************************************
 ** 函数名称:YLZService() 
 ** 函数功能:实现 网络发送相关 的功能
 ** 参    数: 
* @iMode 请求模式，0:同步，1：异步
**********************************************************/
function YLZService(iMode) {    
    var wsObj;
    var localUrl;
    var callback;
    this.requestMode = iMode;

    var CreatLongSocket = function(url, intro){
        var lockReconnect = false; //避免重复连接
        var timeoutFlag = true;
        var timeoutSet = null;
        var reconectNum = 0;
        var timeout = 30000; //超时重连间隔
        var count = 0;
    
        function reconnect() {
            if (lockReconnect) return;
            lockReconnect = true;
            //没连接上会一直重连，设置延迟避免请求过多
            //if (reconectNum < 3) {
            setTimeout(function() {
                timeoutFlag = true;
                createWebSocket();
                console.info(intro+'正在重连第'+reconectNum+'次');
                reconectNum++;
                lockReconnect = false;
            }, 5000); //这里设置重连间隔(ms)
            //}
        }
        //心跳检测
        var heartCheck = {
            timeout: 5000, //毫秒
            timeoutObj: null,
            serverTimeoutObj: null,
            reset: function() {
            clearInterval(this.timeoutObj);
            clearTimeout(this.serverTimeoutObj);
            return this;
            },
            start: function() {
                var self = this;
                
                this.timeoutObj = setInterval(function(){
                if (count < 3) {
                if (wsObj.readyState === 1) {
                    wsObj.send('HeartBeat');
                    console.info(intro+'HeartBeat第'+count +'次');
                }
                count++;
                } else {
                clearInterval(this.timeoutObj);
                count = 0;
                if (wsObj.readyState === 0 && wsObj.readyState === 1) {
                    wsObj.close();
                }
                }
            }, self.timeout);
            }
        } 
        var createWebSocket = function() {
            console.info(intro+'创建');
            timeoutSet = setTimeout(function(){
            if (timeoutFlag && reconectNum < 3) {
                console.info(intro+'重连');
                reconectNum++;
                createWebSocket();
            }
            }, timeout);
            wsObj = new WebSocket(url);
    
            wsObj.onopen = function(){
            reconectNum = 0;
            timeoutFlag = false;
            clearTimeout(timeoutSet);
            heartCheck.reset().start();
            }
            wsObj.onmessage = function(evt){
            //heartCheck.reset().start();
            // console.info(evt);
            if(evt.data === 'HeartBeat') return;
            callback(JSON2.parse(evt.data));
            }
            wsObj.onclose = function(e){
            console.info(intro+'关闭', e.code);
            if (e.code !== 1000) {
                timeoutFlag = false;
                clearTimeout(timeoutSet);
                reconnect();
            } else {
                clearInterval(heartCheck.timeoutObj);
                clearTimeout(heartCheck.serverTimeoutObj);
            }
            }
            wsObj.onerror = function() {
            console.info(intro+'错误');
            wsObj = null;
            reconnect(); //重连
            }
        }
        createWebSocket();
        return wsObj;
    };

    var InitWeb = function(requestMode) {

        if(requestMode == 0)//同步
        {
            localUrl = 'http://127.0.0.1:7776/http/hardware';
        }
        else//异步
        {
            if (window.WebSocket)//优先使用websocket
            {
                //启动websocket连接
                localUrl = 'ws://127.0.0.1:7776';
                CreatLongSocket( localUrl, '易联众WebSocket——');
            }
            else
            {
                localUrl = 'http://127.0.0.1:7776/http/hardware';
            }
        }
    };

    this.SendData = function(Callback,json){
        console.log('发送：' + json);

        if(this.requestMode == 0)//同步
        {
            jQuery.support.cors = true; 
            return jQuery.ajax({  
            type: "post",
            url: localUrl,
            data:json,
            contentType: "application/json;charset=UTF-8",
            crossDomain: true,
            crossDomain:true,
            async: false, // 同步
    
            success: function(data) {  
                var inf = JSON2.stringify(data);
                console.log('接收：' + inf);
            }, 
            error:function(XMLHttpRequest, textStatus, errorThrown)
            {
                var inf= JSON2.stringify(XMLHttpRequest);
                console.log("Http请求错误信息：" + inf);
            }   
            });        
        }
        else//异步
        {
            if(window.WebSocket)//使用websocket
            {
                callback = Callback;
                wsObj.send(json);
            }
            else
            {
                jQuery.support.cors = true; 
                jQuery.ajax({  
                type: "post",
                url: localUrl,
                data:json,
                contentType: "application/json;charset=UTF-8",
                crossDomain: true,
                crossDomain:true,
        
                success: function(data) {  
                    var inf = JSON2.stringify(data);
                    console.log('接收：' + inf);
                    Callback(data);  
                }, 
                error:function(XMLHttpRequest, textStatus, errorThrown)
                {
                    var inf= JSON2.stringify(XMLHttpRequest);
                    console.log("Http请求错误信息：" + inf);
                    Callback(XMLHttpRequest); 
                }   
                });        
            }
        }
       
    };

    InitWeb(this.requestMode);
}



 /**********************************************************
 ** 函数名称:Callback()
 ** 函数功能:实现 示例回调函数处理 的功能
 ** 参    数: 
 @result 返回的JSON结果
**********************************************************/
function Callback(result)
{
    if(result.ResultCode == null)
    {
        alert("网络错误!\r\n\r\n状态值：" + result.readyState + "\r\n状态码：" + result.status + "\r\n状态信息：" +result.statusText + "\r\n\r\n请检查易联众硬件服务是否已正常启动，本地环回网络是否正常！");
    }
	else if(result.FunID == "DKQ0103")
	{
	//	alert("状态代码：" + result.ResultCode + "\r\n功能代码：" + result.FunID + "\r\n返回结果：" + JSON2.stringify(result.ResultData) + "\r\n错误信息：" + result.ErrorInfo);
		var Region = document.getElementById("Region");        
        var DeptID = document.getElementById("DeptID");
		YLZ_Device_TrippleDES_YB(Callback,Region.value,DeptID.value,result.ResultData.DevSerialID,result.ResultData.PSAMTerminalNo,result.ResultData.szMacAddr,result.ResultData.szIpAddr);
	}
	else if(result.FunID == "DKQ0105")
	{
		alert("状态代码：" + result.ResultCode + "\r\n功能代码：" + result.FunID + "\r\n返回结果：" + JSON2.stringify(result.ResultData) + "\r\n错误信息：" + result.ErrorInfo);
		var Region = document.getElementById("Region");        
        var DeptID = document.getElementById("DeptID");
		var Mode = "2";
		YLZ_Device_Decode(Callback,Region.value,DeptID.value,Mode,result.ResultData);
	}
    else if(result.FunID=="DKQ1001")
    {
        var info = document.getElementById("info"); 
        info.value = JSON2.stringify(result.ResultData);  
        alert("状态代码：" + result.ResultCode + "\r\n功能代码：" + result.FunID + "\r\n返回结果：" + JSON2.stringify(result.ResultData) + "\r\n错误信息：" + result.ErrorInfo);
        
    }
    else
    {
        alert("状态代码：" + result.ResultCode + "\r\n功能代码：" + result.FunID + "\r\n返回结果：" + JSON2.stringify(result.ResultData) + "\r\n错误信息：" + result.ErrorInfo);
    }
}